module hsmc_neek_lcd_interface             
(
	//HSMC interface  
	inout	[35:0]			hsmc_d_a,
	inout	[75:40]			hsmc_d_b,
	input				hsmc_clk_in0,
	output				hsmc_clk_out0,
	inout				hsmc_sda,
	inout				hsmc_scl,
	inout	[2:1]			hsmc_clkout_p,
	inout	[2:1]			hsmc_clkout_n,
	input	[2:1]			hsmc_clkin_p,
	input	[2:1]			hsmc_clkin_n,
	                                                                      
	//Eth Interface
	input				local_eth_reset_n,
	output				local_eth_tx_clk,
	input				local_eth_tx_en,
	input	[3:0]			local_eth_tx_d,
	output				local_eth_rx_clk,
	output				local_eth_rx_dv,
	output				local_eth_rx_crs,
	output				local_eth_rx_err,
	output				local_eth_rx_col,
	output	[3:0]			local_eth_rx_d,
	input				local_eth_mdio_out,
	output				local_eth_mdio_in,
	input				local_eth_mdio_oen,
	input				local_eth_mdc,

	//VGA Interface
	input	[9:0]			local_vga_data, 
	input				local_vga_blank,        
	input				local_vga_sync,
	input				local_vga_hs,  
	input				local_vga_vs,  
	input				local_vga_clk,
	
	//PS2 Interface   
	input				local_ps2_clk,
	output				local_ps2_dat,

	//Audio Interface
	input				local_aud_bclk,
	input				local_aud_xck,
	input				local_aud_dacdat,               
	input				local_aud_daclrck,
	output				local_aud_adcdat,
	input				local_aud_adclrck,
	
	//LCD Interface   
	input				local_lcd_vd,
	input				local_lcd_den,
	input				local_lcd_hd,
	input				local_lcd_nclk,
	input	[7:0]			local_lcd_data,
	input				local_lcd_reset_n,
	input				local_lcd_scen,  
	inout				local_lcd_sda,
	input				local_lcd_scl,
	
	//SDMMC Interface 
	input				local_sd_cmd,
	inout				local_sd_dat3,
	inout				local_sd_dat,
	input				local_sd_clk,

	//UART Interface                                           
	output				local_uart_rxd,
	input				local_uart_txd,
	
	//Vid Dec Interface
	output	[7:0]			local_vid_dec_td_d,
	output				local_vid_dec_td_27mhz,
	input				local_vid_dec_td_reset,
	output				local_vid_dec_td_vs,
	output				local_vid_dec_td_hs, 
	
	//Touch Pad       
	input				local_tp_adc_dclk,
	input				local_tp_adc_cs_n,
	input				local_tp_adc_din,
	output				local_tp_adc_dout,
	output				local_tp_adc_penirq_n,
	output				local_tp_adc_busy,
	
	//I2C for a bunch of components
	inout				local_i2c_sclk,
	inout				local_i2c_sdat,
	
	//I2C for ID
	input				local_id_i2c_scl,
	inout				local_id_i2c_sdat
	
);

	
	//Eth Interface
	//Assign to port B pins
	assign	hsmc_d_b[54]		=	local_eth_reset_n;
	assign	local_eth_tx_clk	= 	hsmc_clkin_n[2];
	assign	hsmc_d_b[56]		=	local_eth_tx_en;
	assign 	hsmc_d_b[58]		=	local_eth_tx_d[0];
	assign 	hsmc_d_b[60]		=	local_eth_tx_d[1];
	assign 	hsmc_d_b[62]		=	local_eth_tx_d[2];
	assign 	hsmc_d_b[64]		=	local_eth_tx_d[3];
	assign	local_eth_rx_clk	=	hsmc_clkin_p[1];
	assign	local_eth_rx_dv		=	hsmc_d_b[51];
	assign	local_eth_rx_crs	=	hsmc_d_a[35];
	assign	local_eth_rx_err	=	hsmc_d_a[33];
	assign	local_eth_rx_col	=	hsmc_d_b[49];
	assign	local_eth_rx_d[0]	=	hsmc_d_b[41];
	assign	local_eth_rx_d[1]	=	hsmc_d_b[43];
	assign	local_eth_rx_d[2]	=	hsmc_d_b[45];
	assign	local_eth_rx_d[3]	=	hsmc_d_b[47];
	assign	hsmc_d_b[66]		=	local_eth_mdc;
	assign	hsmc_d_a[6]		=	~local_eth_mdio_oen?local_eth_mdio_out:1'bZ;
	assign	local_eth_mdio_in	=	hsmc_d_a[6];

	//VGA Interface
	assign	hsmc_d_a[16]		=	local_vga_data[0];
	assign	hsmc_d_a[18]		=	local_vga_data[1];
	assign	hsmc_d_a[20]		=	local_vga_data[2];
	assign	hsmc_d_a[22]		=	local_vga_data[3];
	assign	hsmc_d_a[24]		=	local_vga_data[4];
	assign	hsmc_d_a[26]		=	local_vga_data[5];
	assign	hsmc_d_a[28]		=	local_vga_data[6];
	assign	hsmc_d_a[30]		=	local_vga_data[7];
	assign	hsmc_d_a[32]		=	local_vga_data[8];
	assign	hsmc_d_a[34]		=	local_vga_data[9];
	assign	hsmc_d_a[12]		=	local_vga_blank;
	assign	hsmc_d_a[14]		=	local_vga_sync;                                
	assign	hsmc_d_a[9]		=	local_vga_hs;                                   
	assign	hsmc_d_a[10]		=	local_vga_vs;
	assign	hsmc_clkout_n[1]	=	local_vga_clk;   
	
      
	//PS2 Interface   
	assign hsmc_d_a[2]		=	local_ps2_clk;                                
	assign local_ps2_dat		=	hsmc_d_a[4];
	
	//Audio Interface                                         
	assign	hsmc_d_b[48]		=	local_aud_bclk;
	assign	hsmc_clk_out0		=	local_aud_xck;
	assign	hsmc_d_b[46]		=	local_aud_dacdat;
	assign	hsmc_d_b[44]		=	local_aud_daclrck;
	assign	local_aud_adcdat	=	hsmc_clk_in0;
	assign	hsmc_d_b[42]		=	local_aud_adclrck;
	
	//LCD Interface   
	assign	hsmc_d_b[61]		=	local_lcd_vd;
	assign	hsmc_d_b[65]		=	local_lcd_den;
	assign	hsmc_d_b[63]		=	local_lcd_hd;
	assign	hsmc_clkout_p[1]	=	local_lcd_nclk;
	assign	hsmc_d_b[70]		=	local_lcd_data[0];
	assign	hsmc_d_b[72]		=	local_lcd_data[1];
	assign	hsmc_d_b[74]		=	local_lcd_data[2];
	assign	hsmc_d_b[57]		=	local_lcd_data[3];
	assign	hsmc_d_b[59]		=	local_lcd_data[4];
	assign	hsmc_d_b[71]		=	local_lcd_data[5];          
	assign	hsmc_d_b[73]		=	local_lcd_data[6];
	assign	hsmc_d_b[75]		=	local_lcd_data[7];
	assign	hsmc_d_b[67]		=	local_lcd_reset_n;
	assign	hsmc_d_b[69]		=	local_lcd_scen; 
	assign	hsmc_d_a[7]		=	local_lcd_sda;

	//SDMMC Interface
	assign 	hsmc_d_b[40]		=	local_sd_clk;
	assign	hsmc_d_a[8]		=	local_sd_dat3;
	assign	local_sd_dat		=	hsmc_d_a[5]; //in serial mode only input
	assign	hsmc_d_a[3]		=	local_sd_cmd;	
	
	//UART Interface
	assign	local_uart_rxd		=	hsmc_d_b[50];
	assign	hsmc_d_b[52]		=	local_uart_txd;

	//Vid Dec Interface             
	assign	local_vid_dec_td_27mhz	=	hsmc_clkin_n[1];
	assign	hsmc_d_a[27]		=	local_vid_dec_td_reset;
	assign	local_vid_dec_td_d[0]	=	hsmc_d_a[11];
	assign	local_vid_dec_td_d[1]	=	hsmc_d_a[13];
	assign	local_vid_dec_td_d[2]	=	hsmc_d_a[15];
	assign	local_vid_dec_td_d[3]	=	hsmc_d_a[17];
	assign	local_vid_dec_td_d[4]	=	hsmc_d_a[19];
	assign	local_vid_dec_td_d[5]	=	hsmc_d_a[21];
	assign	local_vid_dec_td_d[6]	=	hsmc_d_a[23];
	assign	local_vid_dec_td_d[7]	=	hsmc_d_a[25];
	assign	local_vid_dec_td_vs	=	hsmc_d_a[29];
	assign	local_vid_dec_td_hs	=       hsmc_d_a[31];
	                                   
	//Touch Pad
	//This is a shared clock for the lcd I2C and the TP ADC       	
	assign	hsmc_clkout_n[2]	=	~local_tp_adc_cs_n?local_tp_adc_dclk:(~local_lcd_scen:local_lcd_scl: 0);
	assign	hsmc_d_b[68]		=	local_tp_adc_cs_n;
	assign	hsmc_clkout_p[2]	=	local_tp_adc_din;
	assign	local_tp_adc_dout	=	hsmc_d_b[55];
	assign	local_tp_adc_penirq_n	=       hsmc_clkin_p[2];
	assign	local_tp_adc_busy	=	hsmc_d_b[53];                                        

	//I2C for a bunch of components
	//always enabled
	assign	hsmc_scl		=	local_i2c_sclk;
	assign	hsmc_sda		=	local_i2c_sdat;         
	                                       
	//ID I2C
	assign	hsmc_d_a[0]		=	local_id_i2c_scl;
	assign	hsmc_d_a[1]		=	local_id_i2c_sdat;

		                                          
	
endmodule
